@@ -1,9 +1,9 @@
 package SMOP;
 BEGIN {
-  $SMOP::VERSION = '0.4';
+  $SMOP::VERSION = '0.5';
 }
 # ABSTRACT: Simple Meta Object Programming
-my @MODULES = qw(s0native dump nagc util capture interpreter mold yeast native lost s1p p6opaque s1p-oo mold-message profile p5);
+my @MODULES = qw(s0native dump nagc util capture interpreter mold yeast native lost s1p p6opaque s1p-oo mold-message profile p5 main);
 use File::ShareDir qw(dist_dir);
 use ExtUtils::Embed qw(ldopts ccopts);
 use strict;
@@ -23,4 +23,7 @@ sub include_flags {
 sub ld_library_path {
     dist_dir('SMOP');
 }
+sub modules {
+    @MODULES;
+}
 1;
